==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_SpinEvent.h <==
//----------------------------------------------------------------------------
// wxSpinEvent
// extracted from spinevt.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_SPINEVENT_H__
#define __CLASS_WX_SPINEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxSpinEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_SpinEvent);

//----------------------------------------------------------------------------
// Object declaration for wxSpinEvent
//----------------------------------------------------------------------------
class Object_wx_SpinEvent : public Object_wx_NotifyEvent {
public:
	Gura_DeclareObjectAccessor(wx_SpinEvent)
public:
	inline Object_wx_SpinEvent(wxSpinEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_NotifyEvent(Gura_UserClass(wx_SpinEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_SpinEvent(Class *pClass, wxSpinEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_NotifyEvent(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_SpinEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxSpinEvent *GetEntity() {
		return dynamic_cast<wxSpinEvent *>(_pEntity);
	}
	inline wxSpinEvent *ReleaseEntity() {
		wxSpinEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxSpinEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_SpinEvent.h <==
//----------------------------------------------------------------------------
// wxSpinEvent
// extracted from spinevt.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_SPINEVENT_H__
#define __CLASS_WX_SPINEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxSpinEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_SpinEvent);

//----------------------------------------------------------------------------
// Object declaration for wxSpinEvent
//----------------------------------------------------------------------------
class Object_wx_SpinEvent : public Object_wx_NotifyEvent {
public:
	Gura_DeclareObjectAccessor(wx_SpinEvent)
public:
	inline Object_wx_SpinEvent(wxSpinEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_NotifyEvent(Gura_UserClass(wx_SpinEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_SpinEvent(Class *pClass, wxSpinEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_NotifyEvent(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_SpinEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxSpinEvent *GetEntity() {
		return dynamic_cast<wxSpinEvent *>(_pEntity);
	}
	inline wxSpinEvent *ReleaseEntity() {
		wxSpinEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxSpinEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
